pub struct RtspSource {
pub url: String,
pub key: StreamKey,
}Available on crate features
ingest and rtsp only.Expand description
One RTSP source to pull and the stream key it publishes to.
Fields
url: StringAbsolute rtsp:// URL (credentials, if any, embedded by the host).
key: StreamKeyEngine stream key the pulled media is published under.
Implementations